////////////////////////////////////////////////////////////////////////////
// NoteCase notes manager project <http://notecase.sf.net>
//
// This code is licensed under BSD license.See "license.txt" for more details.
//
// File: this header defines paths for some required files
////////////////////////////////////////////////////////////////////////////

#ifndef CONFIG_H__
#define CONFIG_H__

#define APP_NAME_STR "NoteCase" 
#define APP_VER_STR "1.5.6"

#define PACKAGE "notecase"	//NLS package definition
#define UNDO_LIST_SIZE 10

//#define _ZAURUS_BUILD		//Zaurus specific code

#ifndef _WIN32
#define INSTALL_PREFIX "/usr"
#define HAVE_GNOME_VFS
#endif

#ifdef _WIN32
	#define HELP_FILE_PATH "" 	//calculated dynamically
#else
	#define HELP_FILE_PATH "/share/doc/notecase/help.ncd"	//relative to INSTALL_PREFIX
#endif

#ifdef _WIN32
	#define LOCALE_DIR "" 	//calculated dynamically	
#else
	#define LOCALE_DIR "/share/locale/"	//relative to INSTALL_PREFIX
#endif

#ifndef __MINGW32__
 #define HAVE_SNPRINTF
#endif

#endif

